photonemitter
=============

photonemitter is a modular search system for use with lighthouse.

It allows for many different configurable search providers, making it extremely
simple to simulate things like DuckDuckGo's bangs.

How to use it
-------------

.. code:: bash

        sudo pip install photonemitter

Then, change your lighthouserc to use /usr/bin/photonemitter as cmd.

See the `wiki`_ for more details on configuring photonemitter.

.. _wiki: //github.com/lf-/photonemitter/wiki
